Mandarina
======
**Mandarina** is a friendly personal Data Science library for Python

## Functionality

At the moment, Mandarina provides the follwing modules:
- Csv file functions
- Random data generators 
- Function benchmarking tools
- Tools to work with files and directories

## License 
* Check the [LICENSE](https://github.com/sunpip/Mandarina/blob/master/LICENSE) file

## Authors

- Alen Frey

## Version 
* Version 0.0.3

## How to install
```shell script
pip install mandarina
```
